// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDEVPLATFORM_VERSION_H
#define KDEVPLATFORM_VERSION_H

#define KDEVPLATFORM_VERSION_STRING "6.5.260390"
#define KDEVPLATFORM_VERSION_MAJOR 6
#define KDEVPLATFORM_VERSION_MINOR 5
#define KDEVPLATFORM_VERSION_PATCH 260390
#define KDEVPLATFORM_VERSION ((6<<16)|(5<<8)|(260390))

#endif
